from .agent_based_api.v1 import *

CHECK_DEFAULT_PARAMETERS = {
    "memory_allocation_ratio" : (100.0, 105.0),
    "cpu_allocation_ratio" : (100.0, 105.0)
}

def discover_proxmox_allocation_data(section):
    for line in section:
      key_name = line[0].split(',')[0]
      if 'Ratio' in key_name:
        yield Service(item=key_name)

def check_proxmox_allocation_ratios(item, params, section):
    for line in section:
        service, allocated_ratio, size = line
        allocated_ratio = float(allocated_ratio)
        resource = service.split()[0].lower()
        if resource == 'cpu':
            thresholds = params['cpu']
        elif resource == 'memory':
            thresholds = params['memory']

        if service == item:
            if allocated_ratio > thresholds[1]:
                s = State.CRIT
                detail = f"{resource} exceeds allocation ratio threshold! {allocated_ratio}%"
            elif allocated_ratio > thresholds[0]:
                s = State.WARN
                detail = f"{resource} exceeds allocation ratio threshold! {allocated_ratio}%"
            else:
                s = State.OK
                detail = f"{resource} allocated at {allocated_ratio}%"

            yield Metric(
                "allocation_percent",
                float(allocated_ratio),
                )

            yield Result(
                state = s,
                summary = detail
                )
            return


register.check_plugin(
    name="pve_allocation_ratio",
    service_name="Proxmox %s ",
    discovery_function = discover_proxmox_allocation_data,
    check_function=check_proxmox_allocation_ratios,
    check_default_parameters = CHECK_DEFAULT_PARAMETERS, 
    check_ruleset_name = "pve_allocation_ratio"
)
